Range-v3: ranges::v3::adl_advance_detail::advance_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::adl_advance_detail::advance_fn Struct Reference

## Public Member Functions
template<typename I , requires = (Iterator<I>())>
void | operator() (I &i, difference_type_t< I > n) const
template<typename I , typename S , requires = (Sentinel<S, I>() && Assignable<I&, S>())>
void | operator() (I &i, S s) const
template<typename I , typename S , requires = (Sentinel<S, I>() && !Assignable<I&, S>())>
void | operator() (I &i, S s) const
template<typename I , typename S , requires = (Sentinel<S, I>())>
difference_type_t< I > | operator() (I &it, difference_type_t< I > n, S bound) const